/*  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Script: ws-extra.js         v3.0.2
 *  Author: Neil Thomas       Mar 2024
 *  Last Edit:  2024/03/15
 *  Role:
 *      To provide specific scripts for
 *      the default website
 *  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


//  Other global vars
var cmxData;            //  Holds data collected
let dataPath = '';      //  If you upload data to another folder set to the path required
let initialLoad = true;

let load_menu = 'js/my-menu.js';    //  Menu file to load - path is relative to page
let menu = "";                      //  Placeholders for menus
let mobileMenu = "";
//  Add page filenames for those pages that need to update regularly
let activePages = ['index', 'today', 'todayVyest', 'template'];
//  Check path ending
if( dataPath.length > 0 && dataPath[-1] != '/') { dataPath += '/'; }

//  Collect page data

let getPageData = function( resolve, reject) {
    $.getJSON( dataPath + 'websitedata.json?_=' + Date.now(), function(  json ){
        let pageName = window.location.href.split('/').pop().split('.')[0];
        if( activePages.indexOf( pageName ) >= 0 || pageName == '') {
            setTimeout( function() {
                getPageData( null, null );
            }, 60 * 1000);
        }

        cmxData = json ;

        //  Adjust header values
        $(document).prop('title', cmxData.location + ' weather');
		$('meta[name=description]').attr('content', cmxData.location + ' weather data');
		$('meta[name=keywords]').attr('content', $('meta[name=keywords]').attr('content') + ', ' + cmxData.location);

        if( initialLoad ) {
            $.getScript( load_menu, function() {
                createMainMenu( menuSrc, false );
                createMobileMenu( menuSrc, false );
            });
            initialLoad = false;
        }

        //  Show ~ Hide 'Apparent / FeelsLike' elements
        if( cmxData.options.useApparent === '1' ) {
            $('[data-cmx-Apparent]').removeClass('w3-hide');
            $('[data-cmx-FeelsLike]').addClass('w3-hide');
        }

        // Show ~ Hide 'Solar' elements
        if( cmxData.options.showSolar === '1' ) {
            $('[data-cmx-Solar]').removeClass('w3-hide');
        } else {
            $('[data-cmx-SolarGauge]').addClass( 'w3-hide' );
        }

        // Show ~ Hide 'UV' elements
        if( cmxData.options.showUV === '1' ){
            $('[data-cmx-UV]').removeClass('w3-hide');
        } else {
            $('[data-cmx-UVGauge]').addClass('w3-hide');
        }

        //  Show ~ Hide 'current conditions' element
        if( cmxData.currcond != '' ) {
            $('[data-cmxCurrCond]').removeClass('w3-hide');
        } else {
            $('[data-cmxCurrCond]').addClass('w3-hide');
        }

        // Update all spans with data-cmxData tags
        $('[data-cmxData]').each( function() {
            this.innerHTML = cmxData[this.dataset.cmxdata];
        });

        //  Show / Hide Lightning strikes if NONE today
        if( typeof(cmxData.LightningTime)=="undefined" || cmxData.LightningTime == "---") {
            $('[data-cmxData-Lightning').addClass('w3-hide');
        } else {
            if( cmxData.LightningStrikesToday == "0") {
                $('[data-cmxData-Strikes]').addClass('w3-hide');
            } else {
                $('data-cmxData-Strikes').removeClass('w3-hide');
            }
        }


        //  Add the time of the last rainfall
        $('[data-cmxData="LastRainTime"]').text( cmxData.LastRainTipISO.slice(-5,20));

        if (null !== resolve) {
			resolve();
		}
    })
    .fail( function( jqxhr, textStatus, error) {
        let err = textStatus + ', ' + error;
        console.log('Data request failed: ' + err );

        if( null !== reject) {
            reject;
        }

        setTimeout( function() {
            getPageData( resolve, reject );
        }, 5000 );
    })
}

//  Website menus
let createMainMenu = function(src, submenu) {
    let classMain = 'w3-bar-item w3-btn ow-theme-hvr w3-hide-small w3-hide-medium';
    let classMainSub = 'w3-bar-item w3-btn ow-theme-sub5-hvr';

    src.forEach(function(itm) {
        if (itm.menu !== 'n') { // wanted in main menu
            if (itm.submenu) { // drop down
                menu += '<div class="w3-dropdown-hover">\n';
                menu += '\t<button id="' +  itm.title.replace(/ /g,"_") + 
                    '" type="button" class="w3-btn ow-theme-hvr w3-hide-medium w3-hide-small" onclick="dropDown(this)" aria-expanded="false" >' + 
                    itm.title + '<i class="fa-solid fa-caret-down fa-2xs ow-caret"></i></button>\n';
                menu += '\t<div id="sub_' +  itm.title.replace(/ /g,"_") + '" class="w3-dropdown-content ow-card ow-theme-add2 ow-animate-drop w3-bar-block" style="min-width:15em;">\n';
                // add the sub-menu items
                createMainMenu(itm.items, true);
                menu += '\t\n</div></div>\n';
            } else {
                infill = (itm.new_window ? ' target="_blank"' : '');

                if (itm.forum) {
                     if (cmxData.forumurl != '') {
                        menu += '<a href="' + cmxData.forumurl + '"' + infill + ' class="' + (submenu ? classMainSub : classMain) + '">' + itm.title + '</a>\n';
                     }
                } else if (itm.webcam) {
                    if (cmxData.webcamurl != '') {
                        menu += '<a href="' + cmxData.webcamurl + '"' + infill + ' class="' + (submenu ? classMainSub : classMain) + '">' + itm.title + '</a>\n';
                    }
                } else {
                    if (itm.url == "#") {
                        //  Display dividing bar rather than menu item
                        menu += '<div class="ow-divider"></div>';
                    } else {
                        menu += '<a href="' + itm.url + '"' + infill + ' class="' + (submenu ? classMainSub : classMain) + '">' + itm.title + '</a>\n';
                    }
                }
            }
        }
    });

    // if we are processing a sub menu, return to the main loop
    if (submenu)
        return;

    menu += '<button class="w3-bar-item w3-btn ow-theme-hvr w3-hide-large w3-right ow-menuMobile" onClick="toggleMobileMenu(\'Main_Menu_Mobile\')">Menu  <i class="fa-solid fa-bars"></i></button>';

    // stick the menus into the page
    $('#Main_Menu').html(menu);
};

let createMobileMenu = function(src, submenu) {
    let classMobile = 'w3-bar-item w3-btn ow-theme-hvr';
    let styleMobile = submenu ? 'padding-left: 30px !important;' : '';

    src.forEach(function(itm) {
        if (itm.menu !== 'w') { // wanted in narrow menu
        // mobile menu
            if (itm.submenu) {
                mobileMenu += '<div class="w3-dropdown-click">\t<button id="' + itm.title + '" class="';
                mobileMenu += 'w3-btn w3-left-align ow-theme-hvr" onClick="toggleMenu(this)" style="width:100%;">' + 
                    itm.title + '&nbsp;<i class="fa-solid fa-caret-down fa-2xs ow-caret w3-left-align"></i></button>\n';

                mobileMenu += '<div class="w3-dropdown-content ow-card ow-theme-add4 w3-hide" id="menu' + itm.title + '">';

                createMobileMenu(itm.items, true);
                mobileMenu += '</div>\n</div>\n';
            } else {
                infill = (itm.new_window ? " target='_blank'" : "");
                if (itm.forum && cmxData.forumurl != '') {
                    mobileMenu += '<a href="' +  cmxData.forumurl + '"' + infill + ' class="' + classMobile + '" style= "' + styleMobile + '"> ' + itm.title + '</a>\n';
                } else if (itm.webcam && cmxData.webcamurl != '') {
                    mobileMenu += '<a href="' +  cmxData.webcamurl + '"' + infill + ' class="' + classMobile + '" style= "' + styleMobile + '">' + itm.title + '</a>\n';
                } else {
                     if (itm.url == "#") {
                        //  Enables menu to display dividing bar
                        mobileMenu += '<div class="ow-divider"></div>';
                    } else {
                        mobileMenu += '<a href="' +  itm.url + '"' + infill + ' class="' + classMobile + '" style= "' + styleMobile + '">' + itm.title + '</a>\n';
                    }
                }
            }
        }
    });

    // if we are processing a sub menu, return to the main loop
    if (submenu)
        return;

    // stick the menus into the page
    $('#Main_Menu_Mobile').html(mobileMenu);
};

//  Page Ready
let dataLoadedPromise = new Promise((myResolve, myReject) => {
    
    $( function() {
        getPageData(myResolve, myReject);   //  Collects the published website data from 'websitedata.json'
        configPage();
        $('[data-OWdata=Version]').html( '2.2' );
        
    });
});
